#
# spec file for package gummi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gummi
Version:        0.8.3
Release:        3.1
Summary:        Simple LaTeX editor
License:        MIT
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://github.com/alexandervdm/gummi
Source0:        https://github.com/alexandervdm/gummi/releases/download/%{version}/%{name}-%{version}.tar.gz
# https://github.com/alexandervdm/gummi/issues/197
Patch0:         gummi-gcc15.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  texlive-synctex-devel
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(gtksourceview-3.0) >= 3.4
BuildRequires:  pkgconfig(gtkspell3-3.0) >= 3.0
BuildRequires:  pkgconfig(poppler-glib)
Requires:       texlive-latex
Requires:       texlive-synctex
Recommends:     %{name}-lang

%description
Gummi is a LaTeX editor written using the GTK+ toolkit. It was designed with
simplicity in mind, but is useful for both novice and advanced LaTeX writers.

%lang_package

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}/

%files
%doc AUTHORS ChangeLog
%license COPYING
%{_mandir}/man*/*.1%{?ext_man}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}/
%{_libdir}/%{name}/

%files lang -f %{name}.lang

%changelog
* Wed Mar  5 2025 pgajdos@suse.com
- added patches
  fix build with gcc15
  + gummi-gcc15.patch (gh#alexandervdm/gummi#197)
* Wed Feb 19 2025 Atri Bhattacharya <badshah400@gmail.com>
- Drop incorrect Requires on gtkspell (aka libgtkspell0).
- Drop use of obsolete %%suse_update_desktop_file macro.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.3:
  * Multiple fixes to typesetter parsing.
  * Fixed some warnings.
* Fri May 28 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.2:
  * Prevent losing preview pane position on error.
  * Fix issues with certain font (styles) for editor.
  * Fix spell checking using enchant-2.
  * Fix regression exit crash in certain situations.
  * Synctex fix for filenames with special chars.
  * Re-implemented right panel toggling.
  * Several memory leaks plugged.
- Use `%%make_build` instead of `make`.
* Tue Jan 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.8.1:
  * Fix racing crash related to legacy gdk threading.
  * Fix implicit declaration warning.
- Drop gummi-implicit-fortify-decl.patch: Incorporated upstream.
* Tue Dec 24 2019 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
- New patch: gummi-implicit-fortify-decl.patch to fix GCC warning
  for incompatible implicit declaration of built-in function
  'strlen' (gh#alexandervdm/gummi#124).
